@@ -9,9 +9,13 @@ from pythautomata.tests.test_sequence import TestSequence
 from pythautomata.tests.test_dfa_operations import TestDFAOperations
 from pythautomata.tests.test_automata_definitions import TestAutomataDefinitions
 
+def get_all_tests():
+    return [TestPDFAGenerator, TestMinimizer, TestAutomataConvertor, 
+    TestSimpleDFAGenerator, TestAutomataComparison, TestSequence,
+    TestDFAOperations, TestAutomataDefinitions]
 
 def run():
-    test_classes_to_run = [TestPDFAGenerator]
+    test_classes_to_run = get_all_tests()
     loader = TestLoader()
     suites_list = []
     for test_class in test_classes_to_run:
