@@ -135,14 +135,8 @@ class TestAutomataComparison(TestCase):
     def _areEquivalentFAs(self, automaton1, automaton2):
         if type(automaton1) == DFA and type(automaton2) == DFA:
             comparator = DFAComparator()
-        elif type(automaton1) == NFA and type(automaton2) == NFA:
-            comparator = NFAComparator()
         else:
-            if type(automaton1) == DFA:
-                automaton2 = AutomataConverter.convert_nfa_to_dfa(automaton2)
-            else:
-                automaton1 = AutomataConverter.convert_nfa_to_dfa(automaton1)
-            comparator = DFAComparator()
+            comparator = NFAComparator()
         areEquivalent = comparator.are_equivalent(automaton1, automaton2)
         return areEquivalent
 
@@ -155,7 +149,7 @@ class TestAutomataComparison(TestCase):
     def test_wfa_equivalence_reflexiveness(self):
         weightedTomitasAutomata = WeightedTomitasGrammars.get_all_automata()
         comparator = WFAComparator()
-        for wfa in weightedTomitasAutomata:            
+        for wfa in weightedTomitasAutomata:
             assert(comparator.are_equivalent(wfa, wfa))
 
     def test_wfa_equivalence_false_case(self):
@@ -166,4 +160,4 @@ class TestAutomataComparison(TestCase):
                 if i != j:
                     wfa1 = weightedTomitasAutomata[i]
                     wfa2 = weightedTomitasAutomata[j]
-                    assert(not comparator.are_equivalent(wfa1, wfa2))
\ No newline at end of file
+                    assert(not comparator.are_equivalent(wfa1, wfa2))
